@@ -4,9 +4,7 @@ use strict;
 use warnings;
 
 use Dancer2::Plugin;
-use JSON::Syck;    # TODO 2: use Dancer2::Serializer::JSON; instead ?
-
-$Dancer2::Plugin::Locale::VERSION = '0.02';
+$Dancer2::Plugin::Locale::VERSION = '0.03';
 
 package Dancer2::Plugin::Locale::Obj;
 use Locales 0.33 unicode => 1;
@@ -76,9 +74,8 @@ on_plugin_import {
         # TODO 2: POD app w/ charset !utf8 == ick
         eval "package Dancer2::Plugin::Locale::Obj::$tag;use base 'Dancer2::Plugin::Locale::Obj';our \$Encoding='utf8';our \%Lexicon;package Dancer2::Plugin::Locale;";    ## no critic
 
-        $JSON::Syck::ImplicitUnicode = 1;
         no strict 'refs';                                                                                                                                                  ## no critic
-        %{"Dancer2::Plugin::Locale::Obj::$tag\::Lexicon"} = $tag eq 'en' && !-e $file ? () : ( %{ JSON::Syck::LoadFile($file) } );                                         # TODO 1: instead: tie %{"Dancer2::Plugin::Locale::$tag\::Lexicon"}, 'Tie::Hash::ReadonlyStack', JSON::Syck::LoadFile($file);
+        %{"Dancer2::Plugin::Locale::Obj::$tag\::Lexicon"} = $tag eq 'en' && !-e $file ? () : ( %{ _from_json_file($file) } );                                              # TODO 1: instead: tie %{"Dancer2::Plugin::Locale::$tag\::Lexicon"}, 'Tie::Hash::ReadonlyStack', _from_json_file($file);
     }
 
     # TODO 2: Is there a better way to add template keyword?
@@ -86,12 +83,20 @@ on_plugin_import {
         Dancer2::Core::Hook->new(
             name => 'before_template_render',
             code => sub {
-                $_[0]->{locale} ||= sub { locale( $dsl, @_ ) }
-            },                                                                                                                                                             # TODO 2. YAGNI? _[mt] => sub { locale->makevar(@_) } to parser
+                $_[0]->{locale} = sub { $dsl->locale(@_) };
+            },
         )
     );
 };
 
+sub _from_json_file {
+    my ($file) = @_;
+    open( my $fh, '<', $file ) or die "Could not read “$file”: $!";
+    return from_json(
+        do { local $/; <$fh> }
+    );
+}
+
 # TODO 2: localization tips
 # TODO 2: extractor/checker tool
 
@@ -109,7 +114,7 @@ Dancer2::Plugin::Locale - Localize your Dancer2 application
 
 =head1 VERSION
 
-This document describes Dancer2::Plugin::Locale version 0.02
+This document describes Dancer2::Plugin::Locale version 0.03
 
 =head1 SYNOPSIS
 
@@ -259,8 +264,6 @@ L<Locales>
 
 L<File::Spec>
 
-L<JSON::Syck>
-
 =head1 INCOMPATIBILITIES
 
 None reported.
